==> stock_indicators-1.3.0.tar.gz: stock_indicators-1.3.0/README.md <==
[![image](https://raw.githubusercontent.com/facioquo/stock-indicators-python/main/docs/assets/social-banner.png)](https://python.stockindicators.dev/)

[![PyPI](https://img.shields.io/pypi/v/stock-indicators?color=blue&label=PyPI)](https://badge.fury.io/py/stock-indicators)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/stock-indicators?style=flat&logo=Python&logoColor=white&label=Downloads&color=indigo&link=https%3A%2F%2Fpypistats.org%2Fpackages%2Fstock-indicators)](https://pypistats.org/packages/stock-indicators)

# Stock Indicators for Python

**Stock Indicators for Python** is a PyPI library package that produces financial market technical indicators.  Send in historical price quotes and get back desired indicators such as moving averages, Relative Strength Index, Stochastic Oscillator, Parabolic SAR, etc.  Nothing more.

It can be used in any market analysis software using standard OHLCV price quotes for equities, commodities, forex, cryptocurrencies, and others.  We had private trading algorithms, machine learning, and charting systems in mind when originally creating this community library.  [Stock Indicators for .NET](https://dotnet.stockindicators.dev/) is also available.

Visit our project site for more information:

- [Overview](https://python.stockindicators.dev/)
- [Indicators and overlays](https://python.stockindicators.dev/indicators/)
- [Guide and Pro tips](https://python.stockindicators.dev/guide/)
- [Release notes](https://github.com/facioquo/stock-indicators-python/releases)
- [Discussions](https://github.com/DaveSkender/Stock.Indicators/discussions)
- [Contributing](https://github.com/facioquo/stock-indicators-python/blob/main/docs/contributing.md#readme)

==> stock_indicators-1.3.1.tar.gz: stock_indicators-1.3.1/README.md <==
[![image](https://raw.githubusercontent.com/facioquo/stock-indicators-python/main/docs/assets/social-banner.png)](https://python.stockindicators.dev/)

[![PyPI](https://img.shields.io/pypi/v/stock-indicators?color=blue&label=PyPI)](https://badge.fury.io/py/stock-indicators)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/stock-indicators?style=flat&logo=Python&logoColor=white&label=Downloads&color=indigo&link=https%3A%2F%2Fpypistats.org%2Fpackages%2Fstock-indicators)](https://pypistats.org/packages/stock-indicators)

# Stock Indicators for Python

**Stock Indicators for Python** is a PyPI library package that produces financial market technical indicators.  Send in historical price quotes and get back desired indicators such as moving averages, Relative Strength Index, Stochastic Oscillator, Parabolic SAR, etc.  Nothing more.

It can be used in any market analysis software using standard OHLCV price quotes for equities, commodities, forex, cryptocurrencies, and others.  We had trading algorithms, machine learning, and charting systems in mind when originally creating this community library.  [Stock Indicators for .NET](https://dotnet.stockindicators.dev/) is also available.

Visit our project site for more information:

- [Overview](https://python.stockindicators.dev/)
- [Indicators and overlays](https://python.stockindicators.dev/indicators/)
- [Guide and Pro tips](https://python.stockindicators.dev/guide/)
- [Release notes](https://github.com/facioquo/stock-indicators-python/releases)
- [Discussions](https://github.com/DaveSkender/Stock.Indicators/discussions)
- [Contributing](https://github.com/facioquo/stock-indicators-python/blob/main/docs/contributing.md#readme)
